andes.routines package
======================

Submodules
----------

andes.routines.base module
--------------------------

.. automodule:: andes.routines.base
   :members:
   :undoc-members:
   :show-inheritance:

andes.routines.eig module
-------------------------

.. automodule:: andes.routines.eig
   :members:
   :undoc-members:
   :show-inheritance:

andes.routines.pflow module
---------------------------

.. automodule:: andes.routines.pflow
   :members:
   :undoc-members:
   :show-inheritance:

andes.routines.tds module
-------------------------

.. automodule:: andes.routines.tds
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: andes.routines
   :members:
   :undoc-members:
   :show-inheritance:
